%% Initialize and run scripts
%% Author:  Jakob Stensvik Jensen
%% Date:    4/6-2020 
close all

%% Simulation parameters
t_stop = 200;           % Simulation time
h = 0.01;               % Step size
p_0 = [-14;-2];         % Initial position
p_t = [0;0];            % Destination
wp = [p_0 p_t];         % WPs
v_c = [0.0071;-0.0071]; % Current velocity

%% OS parameters
eta_0 = [p_0' atan2(p_t(2) - p_0(2),...
    p_t(1) - p_0(1))]';     % Initial position and heading  
% Speed assignment on s_1
u_d = 0.1;                  % Reference speed
Delta_p_1 = 0.01;           % Gain for hyperbolic function
mu_1 = 0.01;                % Non-negative tuning constant
% Speed assignment on s_2
u_N = 0.1;                  % Desired speed along the normal vector path
d_safe = 2.5;               % Safety distance from nominal path
Delta_p_2 = 3.5;            % Gain for hyperbolic function (d_ref)
Delta_p_3 = 1;              % Gain for hyperbolic function (d_tilde)
Delta_p_4 = 2;              % Gain for hyperbolic function (s_2)
mu_2 = 0;                   % Non-negative tuning constant

%% TS parameters
r_TS = 0.5;                     % Radius of obstacle
p_0TS = [-5.8;6.2];             % Initial position of TS
vel_TS = [-0.0164;-6*0.0164];   % Velocity of TS 

%% Controller gains
T_1_p = diag([2 1]);    % Time constants for z_1_p-subsystem
T_1_psi = 1;            % Time constant for z_1_psi-subsystem
T_2 = diag([1 1 2]);    % Time constants for z_2-subsystem

%% Observer gains
L_1 = diag([0.05 0.5 0.75]); % Eta gain matrix 
L_2 = diag([5 12.5 2.5]);    % Nu gain matrix 
L_3 = diag([0.15 0.7 0.15]); % Bias gain matrix           

model_matrices          % Load model matrices                
sim('Simulation_CSEI'); % Simulate
plotscript_giveway      % Plot scenario